@@ -76,30 +76,6 @@ public class ListenerInfo extends WhiteboardServiceInfo<EventListener>
         this.types = names.toArray(new String[names.size()]);
     }
 
-    /**
-     * Constructor for Apache Felix proprietary listener support
-     * @param ref The service reference
-     * @param marker Just a marker parameter to distinguish from other constructor
-     */
-    public ListenerInfo(final ServiceReference<EventListener> ref, final boolean marker)
-    {
-        super(ref);
-        this.enabled = true;
-        final String[] objectClass = (String[])ref.getProperty(Constants.OBJECTCLASS);
-        final Set<String> names = new HashSet<String>();
-        for(final String name : objectClass)
-        {
-            if ( ALLOWED_INTERFACES.contains(name) )
-            {
-                names.add(name);
-            }
-        }
-        // remove interfaces not supported by Felix whiteboard
-        names.remove(HttpSessionIdListener.class.getName());
-        names.remove(ServletContextListener.class.getName());
-        this.types = names.toArray(new String[names.size()]);
-    }
-
     @Override
     public boolean isValid()
     {
